==> monica-4.0.0p0.tgz: www/monica/resources/lang/nl/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hoe was je dag? Je kunt hem eens per dag beoordelen.',
    'journal_come_back' => 'Bedankt. Kom morgen terug om je dag opnieuw te beoordelen.',
    'journal_description' => 'Opmerking: het dagboek toont zowel handmatige invoeren als automatische berichten, zoals Activiteiten die je gedaan hebt met je contacten. Je kunt dagboek-invoeren handmatig wissen, maar Activiteiten kunnen alleen op de contact pagina verwijderd worden.',
    'journal_add' => 'Voeg een dagboek-invoer toe',
    'journal_edit' => 'Bewerk dagboek-invoer',
    'journal_empty' => 'Leeg dagboek',
    'journal_created_at' => 'Aangemaakt op {date}',
    'journal_created_automatically' => 'Automatisch aangemaakt',
    'journal_entry_type_journal' => 'Dagboek-invoer',
    'journal_entry_type_activity' => 'Activiteit',
    'journal_entry_rate' => 'Je hebt je dag beoordeeld.',
    'journal_add_comment' => 'Wil je een (optionele) opmerking toevoegen?',
    'journal_show_comment' => 'Toon opmerking',
    'entry_delete_success' => 'De dagboek-invoer is succesvol verwijderd.',
    'journal_add_title' => 'Titel (optioneel)',
    'journal_add_date' => 'Datum',
    'journal_add_post' => 'Invoer',
    'journal_add_cta' => 'Opslaan',
    'journal_blank_cta' => 'Voeg je eerst dagboek-invoer toe',
    'journal_blank_description' => 'Het dagboek laat je gebeurtenissen registreren, zodat je ze kunt onthouden.',
    'delete_confirmation' => 'Weet je zeker dat je deze dagboek-invoer wilt verwijderen?',
];

==> monica-4.1.2p0.tgz: www/monica/resources/lang/nl/journal.php <==
<?php

/**
 * ⚠️ Editing not allowed except for 'en' language.
 *
 * @see https://github.com/monicahq/monica/blob/main/docs/contribute/translate.md for translations.
 */

return [
    'journal_rate' => 'Hoe was je dag? Je kunt hem eens per dag beoordelen.',
    'journal_come_back' => 'Bedankt. Kom morgen terug om je dag opnieuw te beoordelen.',
    'journal_description' => 'Opmerking: het dagboek toont zowel handmatige invoeren als automatische berichten, zoals Activiteiten die je gedaan hebt met je contacten. Je kunt dagboek-invoeren handmatig wissen, maar Activiteiten kunnen alleen op de contact pagina verwijderd worden.',
    'journal_add' => 'Voeg een dagboek-invoer toe',
    'journal_edit' => 'Bewerk dagboek-invoer',
    'journal_empty' => 'Leeg dagboek',
    'journal_created_at' => 'Aangemaakt op {date}',
    'journal_created_automatically' => 'Automatisch aangemaakt',
    'journal_entry_type_journal' => 'Dagboek-invoer',
    'journal_entry_type_activity' => 'Activiteit',
    'journal_entry_rate' => 'Je hebt je dag beoordeeld.',
    'journal_add_comment' => 'Wil je een (optionele) opmerking toevoegen?',
    'journal_show_comment' => 'Toon opmerking',
    'entry_delete_success' => 'De dagboek-invoer is succesvol verwijderd.',
    'journal_add_title' => 'Titel (optioneel)',
    'journal_add_date' => 'Datum',
    'journal_add_post' => 'Invoer',
    'journal_add_cta' => 'Opslaan',
    'journal_blank_cta' => 'Voeg je eerst dagboek-invoer toe',
    'journal_blank_description' => 'Het dagboek laat je gebeurtenissen registreren, zodat je ze kunt onthouden.',
    'delete_confirmation' => 'Weet je zeker dat je deze dagboek-invoer wilt verwijderen?',
    'apply_filter' => 'Apply filter',
    'start_date' => 'Start Date',
    'end_date' => 'End Date',
    'per_page' => 'Per Page',
    'sort_order' => 'Sort By Created At',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
];
